Package: gdata
Version: 3.0.1
Date: 2024-10-22
Title: Various R Programming Tools for Data Manipulation
Authors@R: c(person(c("Gregory", "R."), "Warnes", role="aut", email="greg@warnes.net"),
             person("Gregor", "Gorjanc", role="aut"),
             person("Arni", "Magnusson", role=c("aut","cre"), email="thisisarni@gmail.com"),
             person("Liviu", "Andronic", role="aut"),
             person("Jim", "Rogers", role="aut"),
             person("Don", "MacQueen", role="aut"),
             person("Ales", "Korosec", role="aut"),
             person("Ben", "Bolker", role="ctb"),
             person("Michael", "Chirico", role="ctb"),
             person("Gabor", "Grothendieck", role="ctb"),
             person("Thomas", "Lumley", role="ctb"),
             person("Brian", "Ripley", role="ctb"),
             person("inoui llc", role="fnd"))
Imports: gtools, methods, stats, utils
Suggests: RUnit
Description: Various R programming tools for data manipulation, including
  medical unit conversions, combining objects, character vector operations,
  factor manipulation, obtaining information about R objects, generating
  fixed-width format files, extracting components of date & time objects,
  operations on columns of data frames, matrix operations, operations on
  vectors, operations on data frames, value of last evaluated expression, and a
  resample() wrapper for sample() that ensures consistent behavior for both
  scalar and vector arguments.
License: GPL-3
URL: https://github.com/r-gregmisc/gdata
BugReports: https://github.com/r-gregmisc/gdata/issues
NeedsCompilation: no
Packaged: 2024-10-22 03:06:44 UTC; arnim
Author: Gregory R. Warnes [aut],
  Gregor Gorjanc [aut],
  Arni Magnusson [aut, cre],
  Liviu Andronic [aut],
  Jim Rogers [aut],
  Don MacQueen [aut],
  Ales Korosec [aut],
  Ben Bolker [ctb],
  Michael Chirico [ctb],
  Gabor Grothendieck [ctb],
  Thomas Lumley [ctb],
  Brian Ripley [ctb],
  inoui llc [fnd]
Maintainer: Arni Magnusson <thisisarni@gmail.com>
Repository: CRAN
Date/Publication: 2024-10-22 04:30:02 UTC
Built: R 4.4.0; ; 2026-07-18 04:58:35 UTC; unix
