export(.onAttach,
       ans,
       Args,
       bindData,
       case,
       cbindX,
       centerText,
       combine,
       ConvertMedUnits,
       drop.levels,
       duplicated2,
       env,
       first,
       "first<-",
       frameApply,
       interleave,
       is.what,
       keep,
       last,
       "last<-",
       left,
       ll,
       ls.funs,
       lowerTriangle,
       "lowerTriangle<-",
       matchcols,
       nobs, n_obs,
       nPairs,
       mv,
       rename.vars,
       remove.vars,
       reorder.factor,
       resample,
       right,
       startsWith, starts_with,
       trim,
       trimSum,
       unmatrix,
       update.list,
       update.data.frame,
       upperTriangle,
       "upperTriangle<-",
       wideByFactor,
       write.fwf,

       ## Object size stuff
       object_size, as.object_sizes, is.object_sizes, humanReadable, object.size,

       ## getDateTime stuff
       getYear, getMonth, getDay, getHour, getMin, getSec,

       ## mapLevels stuff
       mapLevels, as.levelsMap, as.listLevelsMap, is.levelsMap, is.listLevelsMap, "mapLevels<-",

       ## unknown stuff
       isUnknown, unknownToNA, NAToUnknown
)

importFrom(stats, reorder)
importFrom(stats, nobs)
importFrom(gtools, mixedsort)
importFrom(methods, is, slot, slotNames)
importFrom(utils, data, head, read.table, tail, write.table)

S3method(reorder, factor)

S3method(summary, nPairs)

## drop.levels stuff
S3method(drop.levels, default)
S3method(drop.levels, factor)
S3method(drop.levels, list)
S3method(drop.levels, data.frame)

## getDateTime stuff
S3method(getYear, default)
S3method(getYear, Date)
S3method(getYear, POSIXct)
S3method(getYear, POSIXlt)

S3method(getMonth, default)
S3method(getMonth, Date)
S3method(getMonth, POSIXct)
S3method(getMonth, POSIXlt)

S3method(getDay, default)
S3method(getDay, Date)
S3method(getDay, POSIXct)
S3method(getDay, POSIXlt)

S3method(getHour, default)

S3method(getMin, default)

S3method(getSec, default)

## mapLevels stuff
S3method(mapLevels, default)
S3method(mapLevels, character)
S3method(mapLevels, factor)
S3method(mapLevels, list)
S3method(mapLevels, data.frame)

S3method("mapLevels<-", default)
S3method("mapLevels<-", list)
S3method("mapLevels<-", data.frame)

S3method(print, levelsMap)
S3method(print, listLevelsMap)

S3method("[", levelsMap)
S3method("[", listLevelsMap)

S3method(c, levelsMap)
S3method(c, listLevelsMap)

S3method(unique, levelsMap)
S3method(sort, levelsMap)

## nobs stuff
S3method(nobs, data.frame)
S3method(nobs, default)
S3method(nobs, lm)

## Object size stuff
S3method(c,      object_sizes)
S3method(format, object_sizes)
S3method(print,  object_sizes)

## unknown stuff
S3method(isUnknown, default)
S3method(isUnknown, POSIXlt)
S3method(isUnknown, list)
S3method(isUnknown, data.frame)
S3method(isUnknown, matrix)

S3method(unknownToNA, default)
S3method(unknownToNA, factor)
S3method(unknownToNA, list)
S3method(unknownToNA, data.frame)

S3method(NAToUnknown, default)
S3method(NAToUnknown, factor)
S3method(NAToUnknown, list)
S3method(NAToUnknown, data.frame)

## trim stuff
S3method(trim, character)
S3method(trim, default)
S3method(trim, factor)
S3method(trim, list)
S3method(trim, data.frame)

## left, right
S3method(left,  data.frame)
S3method(left,  matrix)
S3method(right, data.frame)
S3method(right, matrix)

# update methods for list, data.frame
S3method(update, list)
S3method(update, data.frame)
