Spreadsheet-XLSC version 0.01
=============================

Spreadsheet::XLSX - Perl extension for reading MS Excel 2007 files;

INSTALLATION

To install this module type the following:

   perl Makefile.PL
   make
   make test
   make install

DEPENDENCIES

This module requires these other modules and libraries:

  Archive::Zip

COPYRIGHT AND LICENCE

Copyright (C) 2008 by Dmitry Ovsyanko

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


