NAME
    OLE::Storage_Lite - Simple Class for OLE document interface.

DESCRIPTION
    This module allows you to read and write an OLE-Structured file.

    The module will work on the majority of Windows, UNIX and
    Macintosh platforms.

REQUIREMENT
     Perl 5.005 or later.

INSTALLATION
    The module can be installed using the standard Perl procedure:

        perl Makefile.PL
        make
        make test
        make install    # You may need to be root
        make clean      # or make realclean

    Windows users without a working "make" can get nmake from:
        ftp://ftp.microsoft.com/Softlib/MSLFILES/nmake15.exe

SAMPLE
    Samples scripts are in sample directory.

    smplls.pl : displays PPS structure of specified file
                (subset of "lls" distributed with OLE::Storage)

    smpsv.pl  : creates and save a sample OLE-file(tsv.dat).

AUTHOR
    Kawai Takanori (kwitknr@cpan.org)

